@@ -1,21 +1,23 @@
 /*******************************************************************************
- * (C) Copyright 2010 IBM Corp. 2010
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * (C) Copyright 2010, 2018 IBM Corp. and others.
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0
+ * which is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *    Thavidu Ranatunga (IBM) - Initial implementation.
  *******************************************************************************/
 package org.eclipse.linuxtools.internal.perf.tests;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.BufferedReader;
 import java.io.FileNotFoundException;
@@ -51,17 +53,16 @@ import org.eclipse.linuxtools.internal.perf.ui.PerfProfileView;
 import org.eclipse.linuxtools.profiling.tests.AbstractTest;
 import org.eclipse.ui.PartInitException;
 import org.eclipse.ui.PlatformUI;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.osgi.framework.FrameworkUtil;
-import org.osgi.framework.Version;
 
 public class ModelTest extends AbstractTest {
     private ILaunchConfiguration config;
     private Stack<Class<?>> stack;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         proj = createProjectAndBuild(FrameworkUtil.getBundle(this.getClass()), "fibTest"); //$NON-NLS-1$
         config = createConfiguration(proj.getProject());
@@ -72,7 +73,7 @@ public class ModelTest extends AbstractTest {
         Collections.addAll(stack, klassList);
     }
 
-    @After
+    @AfterEach
     public void tearDown() throws Exception {
         deleteProject(proj);
     }
@@ -324,9 +325,10 @@ public class ModelTest extends AbstractTest {
                 "symbol", "resources/defaultevent-data/perf.data", false);
 
         String[] expectedString = new String[] { PerfPlugin.PERF_COMMAND,
-                "annotate", "-d", "dso", "-s", "symbol", "-l", "-P",
+                "annotate", "--stdio", "-d", "dso", "-s", "symbol", "-l", "-P",
                 "--vmlinux", "/boot/kernel", "-m", "-i",
-                "resources/defaultevent-data/perf.data" };
+                "resources/defaultevent-data/perf.data",
+                "<", "/dev/null" };
 
         assertArrayEquals(expectedString, annotateString);
     }
@@ -347,7 +349,7 @@ public class ModelTest extends AbstractTest {
 
         tempConfig.setAttribute(PerfPlugin.ATTR_DefaultEvent, false);
 
-        String[] recordString = PerfCore.getRecordString(tempConfig, new Version(0, 0, 0));
+        String[] recordString = PerfCore.getRecordString(tempConfig);
         assertNotNull(recordString);
 
         String[] expectedString = { PerfPlugin.PERF_COMMAND, "record",
